
/* Contents *


* Part 1 estimates alternative estimates for TWFE and Event study regressions using AS estimator.

* Part 2 estimates alternative estimates for TWFE and Event study regressions using DD estimator.
* Part 2 estimates biases (negative weights) in TWFE regressions.

* Part 3 estimates biases in Event study regressions

*/


/* Numbers *

mat list dynamic_DID_M : alternatives to coefficients in ES regression using DD estimator (no control)
mat list se_dynamic_DID_M : alternatives' SE to coefficients in ES regression using DD estimator (no control)

mat list ldynamic_DID_M : alternatives to coefficients in ES regression using DD estimator (linear)
mat list lse_dynamic_DID_M : alternatives' SE to coefficients in ES regression using DD estimator (linear)

mat list qdynamic_DID_M : alternatives to coefficients in ES regression using DD estimator (quadratic)
mat list qse_dynamic_DID_M : alternatives' SE to coefficients in ES regression using DD estimator (quadratic)

mat list beta_fe_DID_M : alternative to coefficient in TWFE regression using DD estimator (no control)
mat list se_beta_fe_DID_M : alternative's SE to coefficient in TWFE regression using DD estimator (no control)

mat list lbeta_fe_DID_M : alternative to coefficient in TWFE regression using DD estimator (linear)
mat list lse_beta_fe_DID_M : alternative's SE to coefficient in TWFE regression using DD estimator (linear)

mat list qbeta_fe_DID_M : alternative to coefficient in TWFE regression using DD estimator (quadratic)
mat list qse_beta_fe_DID_M : alternative's SE to coefficient in TWFE regression using DD estimator (quadratic)


mat list dynamic_effect: alternatives to coefficients in ES regression using AS estimator (no control)
mat list se_dynamic_effect: alternatives to coefficients in ES regression using AS estimator (no control)

mat list ldynamic_effect: alternatives to coefficients in ES regression using AS estimator (linear)
mat list lse_dynamic_effect: alternatives to coefficients in ES regression using AS estimator (linear)

mat list qdynamic_effect: alternatives to coefficients in ES regression using AS estimator (quadratic)
mat list qse_dynamic_effect: alternatives to coefficients in ES regression using AS estimator (quadratic)

mat list beta_fe : alternative to coefficient in TWFE regression using AS estimator (no control)
mat list se_beta_fe : alternative's SE to coefficient in TWFE regression using AS estimator (no control)

mat list lbeta_fe : alternative to coefficient in TWFE regression using AS estimator (linear)
mat list lse_beta_fe : alternative's SE to coefficient in TWFE regression using AS estimator (linear)

mat list qbeta_fe: alternative to coefficient in TWFE regression using AS estimator (quadratic)
mat list qse_beta_fe : alternative's SE to coefficient in TWFE regression using AS estimator (quadratic)

mat list sum_nlq : See table 1. 
mat list r14 (row 14) in q_w_el_14: SUm of negative weights in Beta_14 in quadratic specification: -3.610e-16-.00804913-.08873124

*/


/*Part 0* Replication */ 


clear

use "D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData\data\Divorce-Wolfers-AER.dta"
cd D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData

encode st, gen(state) 



*********************Estimate TWFE and ES regressions' coeffcieints with regular DID**************************************

/*
https://www.statalist.org/forums/forum/general-stata-discussion/general/1551834-testing-coefficients-across-weighted-and-unweighted-regressions 
*/

set seed 1234

gen id=_n

expand 2

gen t=_n!=id

replace stpop=1 if t==0

xi i.st i.year i.years_unilateral

*Friedberg and Wolfers - No control* 

reg div_rate unilateral _Iyear_*  _Ist_* if year>1955 & year<1989 [w=stpop] if t==1, cluster(state)
reg div_rate _Iyears_uni_* _Iyear_*  _Ist_* if year>1955 & year<1989 [w=stpop] if t==1, cluster(state)

*Lee and Solon - No control* 

reg div_rate unilateral _Iyear_*  _Ist_* if year>1955 & year<1989 [w=stpop] if t==0, cluster(state)
reg div_rate _Iyears_uni_* _Iyear_*  _Ist_* if year>1955 & year<1989 [w=stpop] if t==0, cluster(state)


*Comparison btw OLS and WLS - No control* 

reg div_rate c.(unilateral _Iyear_*  _Ist_*) i.t i.t#c.(unilateral _Iyear_*  _Ist_*) if year>1955 & year<1989 [w=stpop], cluster(state)

test 1.t#c.unilateral

reg div_rate c.(_Iyears_uni_* _Iyear_* _Ist_*) i.t i.t#c.(_Iyears_uni_* _Iyear_*  _Ist_*  ) if year>1955 & year<1989 [w=stpop], cluster(state)

test 1.t#c._Iyears_uni_2==0
test 1.t#c._Iyears_uni_3==0
test 1.t#c._Iyears_uni_4==0
test 1.t#c._Iyears_uni_5==0
test 1.t#c._Iyears_uni_6==0
test 1.t#c._Iyears_uni_7==0
test 1.t#c._Iyears_uni_8==0
test 1.t#c._Iyears_uni_9==0

xi i.st i.st*time i.st*timesq i.year i.years_unilateral

*Friedberg and Wolfers - Linear trend* 

reg div_rate unilateral _Iyear_*  _Ist_* _IstXtime_* if year>1955 & year<1989 [w=stpop] if t==1, cluster(state)
reg div_rate _Iyears_uni_* _Iyear_*  _Ist_* _IstXtime_* if year>1955 & year<1989 [w=stpop] if t==1, cluster(state)

*Lee and Solon - Linear trend* 

reg div_rate unilateral _Iyear_*  _Ist_* _IstXtime_* if year>1955 & year<1989 [w=stpop] if t==0, cluster(state)
reg div_rate _Iyears_uni_* _Iyear_*  _Ist_* _IstXtime_* if year>1955 & year<1989 [w=stpop] if t==0, cluster(state)

*Comparison btw OLS and WLS - Linear trend* 

reg div_rate c.(unilateral _Iyear_*  _Ist_* _IstXtime_*    ) i.t i.t#c.(unilateral _Iyear_*  _Ist_*  _IstXtime_* ) if year>1955 & year<1989 [w=stpop], cluster(state)

test 1.t#c.unilateral

reg div_rate c.(_Iyears_uni_* _Iyear_*  _Ist_* _IstXtime_*    ) i.t i.t#c.(_Iyears_uni_* _Iyear_*  _Ist_*  _IstXtime_* ) if year>1955 & year<1989 [w=stpop], cluster(state)

test 1.t#c._Iyears_uni_2==0
test 1.t#c._Iyears_uni_3==0
test 1.t#c._Iyears_uni_4==0
test 1.t#c._Iyears_uni_5==0
test 1.t#c._Iyears_uni_6==0
test 1.t#c._Iyears_uni_7==0
test 1.t#c._Iyears_uni_8==0
test 1.t#c._Iyears_uni_9==0

*Friedberg and Wolfers - Quadratic trend* 

reg div_rate unilateral _Iyear_*  _Ist_* _IstXtime_* _IstXtimea* if year>1955 & year<1989 [w=stpop] if t==1, cluster(state)
reg div_rate _Iyears_uni_* _Iyear_*  _Ist_* _IstXtime_* _IstXtimea* if year>1955 & year<1989 [w=stpop] if t==1, cluster(state)

*Lee and Solon - Quadratic trend* 

reg div_rate unilateral _Iyear_*  _Ist_* _IstXtime_* _IstXtimea* if year>1955 & year<1989 [w=stpop] if t==0, cluster(state)
reg div_rate _Iyears_uni_* _Iyear_*  _Ist_* _IstXtime_* _IstXtimea* if year>1955 & year<1989 [w=stpop] if t==0, cluster(state)

*Comparison btw OLS and WLS - Quadratic trend* 

reg div_rate c.(unilateral _Iyear_*  _Ist_* _IstXtime_* _IstXtimea*  ) i.t i.t#c.(unilateral _Iyear_*  _Ist_*  _IstXtime_* _IstXtimea* ) if year>1955 & year<1989 [w=stpop], cluster(state)

test 1.t#c.unilateral

reg div_rate c.(_Iyears_uni_* _Iyear_*  _Ist_* _IstXtime_* _IstXtimea*  ) i.t i.t#c.(_Iyears_uni_* _Iyear_*  _Ist_*  _IstXtime_* _IstXtimea* ) if year>1955 & year<1989 [w=stpop], cluster(state)

test 1.t#c._Iyears_uni_2==0
test 1.t#c._Iyears_uni_3==0
test 1.t#c._Iyears_uni_4==0
test 1.t#c._Iyears_uni_5==0
test 1.t#c._Iyears_uni_6==0
test 1.t#c._Iyears_uni_7==0
test 1.t#c._Iyears_uni_8==0
test 1.t#c._Iyears_uni_9==0




/*Part 1 - AS estimator estimation*/


***********************************************************************************
***********************************************************************************
***********************************************************************************
****************************AS estimator estimation********************************
***********************************************************************************
***********************************************************************************
***********************************************************************************


/* Matrix Definition

mat list alt_beta_fe : weighted average of dynamic effect: alternative for two-way fixed effect estimate
mat list se_beta_fe: se of alternative for two-way fixed effect estmate 

mat list dynamic_fe : weighted average of dynamic effect: focusing dynamic effect 
mat lise se_dynamic_fe : se of weighted average of dynamic effect: focusing dynamic effect 


*/

/* Data Load */

clear

use "D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData\data\Divorce-Wolfers-AER.dta"


cd D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData


encode st, gen(state) 


**********************Generate 1{E_i=e} and D_{i,t}^l in my paper ***********************************

gen event = lfdivlaw  /* Event: Cohort */ 

tab event, gen(event_) /*Generate 1{E_i=e} */
drop event_1 event_2 event_13

rename event_3 event_1
rename event_4 event_2
rename event_5 event_3
rename event_6 event_4
rename event_7 event_5
rename event_8 event_6
rename event_9 event_7
rename event_10 event_8
rename event_11 event_9
rename event_12 event_10

gen itl = year - event /* This will use to make D_{it}^l where l = E_i- t */


*** n_itl \equiv D_{i,t}^l in Abraham paper.***

gen n_itl = -6 if itl<=-11 
replace n_itl = -5 if itl>=-10 & itl<=-9 
replace n_itl = -4 if itl>=-8 & itl<=-7 
replace n_itl = -3 if itl>=-6 & itl<=-5 
replace n_itl = -2 if itl>=-4 & itl<=-3 
replace n_itl = -1 if itl>=-2 & itl<=-1 
replace n_itl = 0 if itl>=0 & itl<=1  
replace n_itl = 1 if itl>=2 & itl<=3  
replace n_itl = 2 if itl>=4 & itl<=5  
replace n_itl = 3 if itl>=6 & itl<=7  
replace n_itl = 4 if itl>=8 & itl<=9   
replace n_itl = 5 if itl>=10 & itl<=11 
replace n_itl = 6 if itl>=12 & itl<=13 
replace n_itl = 7 if itl>=14

tab n_itl,  gen(n_itl_) 

forvalues i= 1/14{
	replace n_itl_`i' = 0 if  lfdivlaw==2000 & year>1955 & year<1989
}


******************Drop groups that are treated for all period.***************************************

drop if lfdivlaw==1935
drop if lfdivlaw==1953


****************Estimate dynamic effect with estimator of Abraham and Sun****************************


**************************Generate 1{E_i=e}*D_{i,t}^l************************************************


drop n_itl_6
local list_itl "n_itl_*"
local list_event "event_1 - event_10"

foreach v of varlist `list_itl' {
	foreach i of varlist `list_event'{
		gen `v'_`i' = `v'*`i'
	}
}
***********Calculate P_{e,l} for CATT_l (CATT_l = \sum_e P_{e,l}* CATT_{e,l})- See page 50 for details *************
/*  Proof of Proposition 6 https://arxiv.org/pdf/1804.05785.pdf  */


estimates clear
local list_event "event_1 - event_10" 
	foreach ee of varlist `list_event'{
		reg `ee' n_itl_1 - n_itl_5 n_itl_7-n_itl_14  if year>1955 & year<1989 [w=stpop], nocons
		estimates store est_`ee'
	}
	
suest est_event_1 est_event_2 est_event_3 est_event_4 est_event_5 est_event_6 est_event_7 est_event_8 est_event_9 est_event_10, vce(robust)


// to store variance covariance in a 15x15 matrix where the 5x5 block corresponds to each regression
matrix V_p = e(V)
//to extract matrix, install package "matselrc"

mat V_p_cov1 = V_p[1..13, 1..13], V_p[1..13, 15..27], V_p[1..13, 29..41], V_p[1..13, 43..55], V_p[1..13, 57..69], V_p[1..13, 71..83], V_p[1..13, 85..97], V_p[1..13, 99..111], V_p[1..13, 113..125], V_p[1..13, 127..139]

mat V_p_cov2 = V_p[15..27, 1..13], V_p[15..27, 15..27], V_p[15..27, 29..41], V_p[15..27, 43..55], V_p[15..27, 57..69], V_p[15..27, 71..83], V_p[15..27, 85..97], V_p[15..27, 99..111], V_p[15..27, 113..125], V_p[15..27, 127..139]

mat V_p_cov3 = V_p[29..41, 1..13], V_p[29..41, 15..27], V_p[29..41, 29..41], V_p[29..41, 43..55], V_p[29..41, 57..69], V_p[29..41, 71..83], V_p[29..41, 85..97], V_p[29..41, 99..111], V_p[29..41, 113..125], V_p[29..41, 127..139]

mat V_p_cov4 = V_p[43..55, 1..13], V_p[43..55, 15..27], V_p[43..55, 29..41], V_p[43..55, 43..55], V_p[43..55, 57..69], V_p[43..55, 71..83], V_p[43..55, 85..97], V_p[43..55, 99..111], V_p[43..55, 113..125], V_p[43..55, 127..139]

mat V_p_cov5 = V_p[57..69, 1..13], V_p[57..69, 15..27], V_p[57..69, 29..41], V_p[57..69, 43..55], V_p[57..69, 57..69], V_p[57..69, 71..83], V_p[57..69, 85..97], V_p[57..69, 99..111], V_p[57..69, 113..125], V_p[57..69, 127..139]

mat V_p_cov6 = V_p[71..83, 1..13], V_p[71..83, 15..27], V_p[71..83, 29..41], V_p[71..83, 43..55], V_p[71..83, 57..69], V_p[71..83, 71..83], V_p[71..83, 85..97], V_p[71..83, 99..111], V_p[71..83, 113..125], V_p[71..83, 127..139]

mat V_p_cov7 = V_p[85..97, 1..13], V_p[85..97, 15..27], V_p[85..97, 29..41], V_p[85..97, 43..55], V_p[85..97, 57..69], V_p[85..97, 71..83], V_p[85..97, 85..97], V_p[85..97, 99..111], V_p[85..97, 113..125], V_p[85..97, 127..139]

mat V_p_cov8 = V_p[99..111, 1..13], V_p[99..111, 15..27], V_p[99..111, 29..41], V_p[99..111, 43..55], V_p[99..111, 57..69], V_p[99..111, 71..83], V_p[99..111, 85..97], V_p[99..111, 99..111], V_p[99..111, 113..125], V_p[99..111, 127..139]

mat V_p_cov9 = V_p[113..125, 1..13], V_p[113..125, 15..27], V_p[113..125, 29..41], V_p[113..125, 43..55], V_p[113..125, 57..69], V_p[113..125, 71..83], V_p[113..125, 85..97], V_p[113..125, 99..111], V_p[113..125, 113..125], V_p[113..125, 127..139]

mat V_p_cov10= V_p[127..139, 1..13], V_p[127..139, 15..27], V_p[127..139, 29..41], V_p[127..139, 43..55], V_p[127..139, 57..69], V_p[127..139, 71..83], V_p[127..139, 85..97], V_p[127..139, 99..111], V_p[127..139, 113..125], V_p[127..139, 127..139]


mat V_p_cov = V_p_cov1 \ V_p_cov2 \ V_p_cov3 \ V_p_cov4 \ V_p_cov5 \ V_p_cov6 \ V_p_cov7 \ V_p_cov8 \ V_p_cov9 \ V_p_cov10
/*V_p_cov : cov matrix except constant*/

mat p_beta = e(b)[1,1..13] , e(b)[1,15..27] , e(b)[1,29..41] , e(b)[1,43..55] , e(b)[1,57..69] , e(b)[1,71..83] , e(b)[1,85..97] , e(b)[1,99..111] , e(b)[1,113..125] , e(b)[1,127..139]



forvalues i = 1/13 {
	mat p_beta_new_`i'= p_beta[1,`i'], p_beta[1,13+`i'], p_beta[1,26+`i'], p_beta[1,39+`i'], p_beta[1,52+`i'], p_beta[1,65+`i'], p_beta[1,78+`i'], p_beta[1,91+`i'], p_beta[1,104+`i'], p_beta[1,117+`i']
	mat p_beta_new_`i'_T = p_beta_new_`i''
}

mat p_beta_new= p_beta_new_1 , p_beta_new_2 , p_beta_new_3 , p_beta_new_4 , p_beta_new_5 , p_beta_new_6 , p_beta_new_7 , p_beta_new_8 , p_beta_new_9 , p_beta_new_10 , p_beta_new_11 , p_beta_new_12 , p_beta_new_13

/*p_beta_new :For estimating average dynamic effect use p_beta_new*/

mat p_beta_new_T = p_beta_new'

forvalues i = 1/130{
	forvalues j=1/13{
	mat e_`i'_`j' = V_p_cov[`i', `j'], V_p_cov[`i', `j'+13], V_p_cov[`i', `j'+26], V_p_cov[`i', `j'+39], V_p_cov[`i', `j'+52], V_p_cov[`i', `j'+65], V_p_cov[`i', `j'+78], V_p_cov[`i', `j'+91], V_p_cov[`i', `j'+104], V_p_cov[`i', `j'+117]
	}
	mat e_`i' = e_`i'_1, e_`i'_2, e_`i'_3, e_`i'_4, e_`i'_5, e_`i'_6, e_`i'_7, e_`i'_8, e_`i'_9, e_`i'_10,  e_`i'_11, e_`i'_12, e_`i'_13       
}

forvalues j=1/13{
	local j1 = `j'
	local j2 = 13+ `j'
	local j3 = 26+ `j'
	local j4 = 39 + `j'
	local j5 = 52 +`j'
	local j6 = 65 + `j'
	local j7 = 78 + `j'
	local j8 = 91 + `j'	
	local j9 = 104 + `j'
	local j10 = 117 + `j'	
	mat true_cov_`j' = e_`j1' \ e_`j2' \ e_`j3' \ e_`j4' \ e_`j5' \ e_`j6' \ e_`j7' \ e_`j8' \ e_`j9' \ e_`j10'
}


mat true_cov_p = true_cov_1 \ true_cov_2 \ true_cov_3 \ true_cov_4 \ true_cov_5 \ true_cov_6 \ true_cov_7 \ true_cov_8 \ true_cov_9 \ true_cov_10 \ true_cov_11 \ true_cov_12 \ true_cov_13

local j=0
forvalues i=1/13{
	mat true_cov_p_`i' = true_cov_p[1+`j'*10..10*`i', 1+`j'*10..10*`i']
	local j = `j'+1
}        

/*true_cov_p :For estimating se of average dynamic effect use true_cov_p*/

* I calculate CATT_{e,l} by using Frisch-Waugh theorem. *
* The reason is because Abraham and Sun calculate variance with residuals in page 51-52.* 
*  Proof of Proposition 6 https://arxiv.org/pdf/1804.05785.pdf  *
* Original regression eqn is (26) in Abraham and Sun -  https://arxiv.org/pdf/1804.05785.pdf *


******************************** No control ******************************************************


xi i.st i.year

local list_nitlevent "n_itl_*_*"

foreach vv of varlist `list_nitlevent' { 
	reg `vv' _Ist_*  _Iyear_*  if year>1955 & year<1989 [w=stpop], cluster(state)
	predict residual, residual
	rename residual residual_`vv'
}


reg div_rate _I* if year>1955 & year<1989 [w=stpop], cluster(state)
predict residual, residual
rename residual y_residual

global rhs_residuals "residual_n_itl_*"

reg y_residual $rhs_residuals if year>1955 & year<1989 [w=stpop], cluster(state)/* (9) in page 12. */


forvalues i = 0/7 {
	mat catt_e_`i' = e(b)[.,(`i'+5)*10+1..(`i'+6)*10]
	mat catt_e_`i'_T = catt_e_`i''
	mat V`i' = e(V)[(`i'+5)*10+1..(`i'+6)*10, (`i'+5)*10+1..(`i'+6)*10]
}

mat catt_e_minus2 = e(b)[.,41..50]
mat catt_e_minus2_T = catt_e_minus2'
mat VM2 = e(V)[41..50,41..50]

mat catt_e_minus3 = e(b)[.,31..40]
mat catt_e_minus3_T = catt_e_minus3'
mat VM3 = e(V)[31..40,31..40]

mat catt_e_minus4 = e(b)[.,21..30]
mat catt_e_minus4_T = catt_e_minus4'
mat VM4 = e(V)[21..30,21..30]

mat catt_e_minus5 = e(b)[.,11..20]
mat catt_e_minus5_T = catt_e_minus5'
mat VM5 = e(V)[11..20,11..20]

mat catt_e_minus6 = e(b)[.,1..10]
mat catt_e_minus6_T = catt_e_minus6'
mat VM6 = e(V)[1..10,1..10]



local j = 6
forvalues i = 0/7 {
	mat beta_`i' = p_beta_new_`j' * catt_e_`i'_T  /*CATT_l = \sum_e P_{e,l}* CATT_{e,l}*/
	local j = `j'+1
	}

mat beta_minus2 =  p_beta_new_5 * catt_e_minus2_T 
mat beta_minus3 =  p_beta_new_4 * catt_e_minus3_T 
mat beta_minus4 =  p_beta_new_3 * catt_e_minus4_T 
mat beta_minus5 =  p_beta_new_2 * catt_e_minus5_T 
mat beta_minus6 =  p_beta_new_1 * catt_e_minus6_T 





matrix dynamic_effect = J(13,1,0)

forvalues i = 0/7 {
	mat dynamic_effect[`i'+6,1] = beta_`i'[1,1]
}
mat dynamic_effect[1,1] = beta_minus6
mat dynamic_effect[2,1] = beta_minus5
mat dynamic_effect[3,1] = beta_minus4
mat dynamic_effect[4,1] = beta_minus3
mat dynamic_effect[5,1] = beta_minus2


mat dynamic_effect_T=dynamic_effect'

local j=6
forvalues i = 0/7 {
mat V`i'_D =  p_beta_new_`j'*V`i'* p_beta_new_`j'_T + catt_e_`i'*true_cov_p_`j'*catt_e_`i'_T 
local j = `j'+1
/*See page 31 for variance of CATT_l*/
}


mat VM6_D = p_beta_new_1*VM6*p_beta_new_1_T + catt_e_minus6 * true_cov_p_1* catt_e_minus6_T
mat VM5_D = p_beta_new_2*VM5*p_beta_new_2_T + catt_e_minus5 * true_cov_p_2* catt_e_minus5_T
mat VM4_D = p_beta_new_3*VM4*p_beta_new_3_T + catt_e_minus4 * true_cov_p_3* catt_e_minus4_T
mat VM3_D = p_beta_new_4*VM3*p_beta_new_4_T + catt_e_minus3 * true_cov_p_4* catt_e_minus3_T
mat VM2_D = p_beta_new_5*VM2*p_beta_new_5_T + catt_e_minus2 * true_cov_p_5* catt_e_minus2_T




 
mat v_dynamic = J(13,1,0)
forvalues i = 0/7 {
	mat v_dynamic[`i'+6,1] = V`i'_D[1,1]
}
mat v_dynamic[1,1] = VM6_D
mat v_dynamic[2,1] = VM5_D
mat v_dynamic[3,1] = VM4_D
mat v_dynamic[4,1] = VM3_D
mat v_dynamic[5,1] = VM2_D


mat se_dynamic = J(13,1,0)
forvalues i = 1/13 {
	mat se_dynamic[`i',1] = v_dynamic[`i',1]^0.5
}

mat t_dynamic = J(13,1,0)
forvalues i = 1/13 {
	mat t_dynamic[`i',1] = dynamic_effect[`i',1]/se_dynamic[`i',1]
}

******************************** Linear Trend ******************************************************

xi i.st i.st*time i.year

local list_nitlevent "n_itl_*_*"

foreach vv of varlist `list_nitlevent' { 
	reg `vv' _Ist_*  _Iyear_*  _IstXtime_* if year>1955 & year<1989 [w=stpop], cluster(state)  
	predict residual, residual
	rename residual lresidual_`vv'
}

reg div_rate _Ist_*  _Iyear_*  _IstXtime_* if year>1955 & year<1989 [w=stpop], cluster(state)
predict residual, residual
rename residual y_lresidual


global rhs_lresiduals "lresidual_n_itl_*"

forvalues i = 1/10 {
	replace  lresidual_n_itl_1_event_`i' = 0
}


*reg div_rate $rhs_lresiduals if year>1955 & year<1989 [w=stpop], cluster(state) robust
reg y_lresidual $rhs_lresiduals if year>1955 & year<1989 [w=stpop], cluster(state)


forvalues i = 0/7 {
	mat lcatt_e_`i' = e(b)[.,(`i'+5)*10+1..(`i'+6)*10]
	mat lcatt_e_`i'_T = lcatt_e_`i''
	mat lV`i' = e(V)[(`i'+5)*10+1..(`i'+6)*10, (`i'+5)*10+1..(`i'+6)*10]
}


mat lcatt_e_minus2 = e(b)[.,41..50]
mat lcatt_e_minus2_T = lcatt_e_minus2'
mat lVM2 = e(V)[41..50,41..50]

mat lcatt_e_minus3 = e(b)[.,31..40]
mat lcatt_e_minus3_T = catt_e_minus3'
mat lVM3 = e(V)[31..40,31..40]

mat lcatt_e_minus4 = e(b)[.,21..30]
mat lcatt_e_minus4_T = lcatt_e_minus4'
mat lVM4 = e(V)[21..30,21..30]

mat lcatt_e_minus5 = e(b)[.,11..20]
mat lcatt_e_minus5_T = lcatt_e_minus5'
mat lVM5 = e(V)[11..20,11..20]

mat lcatt_e_minus6 = e(b)[.,1..10]
mat lcatt_e_minus6_T = lcatt_e_minus6'
mat lVM6 = e(V)[1..10,1..10]


local j = 6
forvalues i = 0/7 {
	mat lbeta_`i' = p_beta_new_`j' * lcatt_e_`i'_T  /*CATT_l = \sum_e P_{e,l}* CATT_{e,l}*/
	local j = `j'+1
	}

mat lbeta_minus2 =  p_beta_new_5 * lcatt_e_minus2_T 
mat lbeta_minus3 =  p_beta_new_4 * lcatt_e_minus3_T 
mat lbeta_minus4 =  p_beta_new_3 * lcatt_e_minus4_T 
mat lbeta_minus5 =  p_beta_new_2 * lcatt_e_minus5_T 
mat lbeta_minus6 =  p_beta_new_1 * lcatt_e_minus6_T 


matrix ldynamic_effect = J(13,1,0)

forvalues i = 0/7 {
	mat ldynamic_effect[`i'+6,1] = lbeta_`i'[1,1]
}


mat ldynamic_effect[1,1] = lbeta_minus6
mat ldynamic_effect[2,1] = lbeta_minus5
mat ldynamic_effect[3,1] = lbeta_minus4
mat ldynamic_effect[4,1] = lbeta_minus3
mat ldynamic_effect[5,1] = lbeta_minus2

local j=6
forvalues i = 0/7 {
mat lV`i'_D =  p_beta_new_`j'*lV`i'* p_beta_new_`j'_T + lcatt_e_`i'*true_cov_p_`j'*lcatt_e_`i'_T 
local j = `j'+1
/*See page 31 for variance of CATT_l*/
}

mat lVM6_D = p_beta_new_1*lVM6*p_beta_new_1_T + lcatt_e_minus6 * true_cov_p_1* lcatt_e_minus6_T
mat lVM5_D = p_beta_new_2*lVM5*p_beta_new_2_T + lcatt_e_minus5 * true_cov_p_2* lcatt_e_minus5_T
mat lVM4_D = p_beta_new_3*lVM4*p_beta_new_3_T + lcatt_e_minus4 * true_cov_p_3* lcatt_e_minus4_T
mat lVM3_D = p_beta_new_4*lVM3*p_beta_new_4_T + lcatt_e_minus3 * true_cov_p_4* lcatt_e_minus3_T
mat lVM2_D = p_beta_new_5*lVM2*p_beta_new_5_T + lcatt_e_minus2 * true_cov_p_5* lcatt_e_minus2_T

mat lv_dynamic = J(13,1,0)
forvalues i = 0/7 {
	mat lv_dynamic[`i'+6,1] = lV`i'_D[1,1]
}
mat lv_dynamic[1,1] = lVM6_D
mat lv_dynamic[2,1] = lVM5_D
mat lv_dynamic[3,1] = lVM4_D
mat lv_dynamic[4,1] = lVM3_D
mat lv_dynamic[5,1] = lVM2_D


mat lse_dynamic = J(13,1,0)
forvalues i = 1/13 {
	mat lse_dynamic[`i',1] = lv_dynamic[`i',1]^0.5
}

mat lt_dynamic = J(13,1,0)
forvalues i = 1/13 {
	mat lt_dynamic[`i',1] = ldynamic_effect[`i',1]/lse_dynamic[`i',1]
}

******************************** Quadratic Trend ******************************************************


xi i.st i.st*time i.st*timesq i.year

local list_nitlevent "n_itl_*_*"

foreach vv of varlist `list_nitlevent' { 
	reg `vv' _I* if year>1955 & year<1989 [w=stpop], cluster(state)
	predict residual, residual
	rename residual qresidual_`vv'
}


reg div_rate _I* if year>1955 & year<1989 [w=stpop], cluster(state)
predict residual, residual
rename residual y_qresidual

global rhs_qresiduals "qresidual_n_itl_*"




forvalues i = 1/10 {
	replace  qresidual_n_itl_1_event_`i' = 0
}



*reg div_rate $rhs_qresiduals if year>1955 & year<1989 [w=stpop], cluster(state) robust
reg y_qresidual $rhs_qresiduals if year>1955 & year<1989 [w=stpop], cluster(state)



forvalues i = 0/7 {
	mat qcatt_e_`i' = e(b)[.,(`i'+5)*10+1..(`i'+6)*10]
	mat qcatt_e_`i'_T = qcatt_e_`i''
	mat qV`i' = e(V)[(`i'+5)*10+1..(`i'+6)*10, (`i'+5)*10+1..(`i'+6)*10]
}

mat qcatt_e_minus2 = e(b)[.,41..50]
mat qcatt_e_minus2_T = qcatt_e_minus2'
mat qVM2 = e(V)[41..50,41..50]

mat qcatt_e_minus3 = e(b)[.,31..40]
mat qcatt_e_minus3_T = qcatt_e_minus3'
mat qVM3 = e(V)[31..40,31..40]

mat qcatt_e_minus4 = e(b)[.,21..30]
mat qcatt_e_minus4_T = qcatt_e_minus4'
mat qVM4 = e(V)[21..30,21..30]

mat qcatt_e_minus5 = e(b)[.,11..20]
mat qcatt_e_minus5_T = qcatt_e_minus5'
mat qVM5 = e(V)[11..20,11..20]

mat qcatt_e_minus6 = e(b)[.,1..10]
mat qcatt_e_minus6_T = qcatt_e_minus6'
mat qVM6 = e(V)[1..10,1..10]


local j = 6
forvalues i = 0/7 {
	mat qbeta_`i' = p_beta_new_`j' * qcatt_e_`i'_T  /*CATT_l = \sum_e P_{e,l}* CATT_{e,l}*/
	local j = `j'+1
	}

mat qbeta_minus2 =  p_beta_new_5 * qcatt_e_minus2_T 
mat qbeta_minus3 =  p_beta_new_4 * qcatt_e_minus3_T 
mat qbeta_minus4 =  p_beta_new_3 * qcatt_e_minus4_T 
mat qbeta_minus5 =  p_beta_new_2 * qcatt_e_minus5_T 
mat qbeta_minus6 =  p_beta_new_1 * qcatt_e_minus6_T 

matrix qdynamic_effect = J(13,1,0)

forvalues i = 0/7 {
	mat qdynamic_effect[`i'+6,1] = qbeta_`i'[1,1]
}

mat qdynamic_effect[1,1] = qbeta_minus6
mat qdynamic_effect[2,1] = qbeta_minus5
mat qdynamic_effect[3,1] = qbeta_minus4
mat qdynamic_effect[4,1] = qbeta_minus3
mat qdynamic_effect[5,1] = qbeta_minus2


local j=6
forvalues i = 0/7 {
mat qV`i'_D =  p_beta_new_`j'*qV`i'* p_beta_new_`j'_T + qcatt_e_`i'*true_cov_p_`j'*qcatt_e_`i'_T 
local j = `j'+1
/*See page 31 for variance of CATT_l*/
}

mat qVM6_D = p_beta_new_1*qVM6*p_beta_new_1_T + qcatt_e_minus6 * true_cov_p_1* qcatt_e_minus6_T
mat qVM5_D = p_beta_new_2*qVM5*p_beta_new_2_T + qcatt_e_minus5 * true_cov_p_2* qcatt_e_minus5_T
mat qVM4_D = p_beta_new_3*qVM4*p_beta_new_3_T + qcatt_e_minus4 * true_cov_p_3* qcatt_e_minus4_T
mat qVM3_D = p_beta_new_4*qVM3*p_beta_new_4_T + qcatt_e_minus3 * true_cov_p_4* qcatt_e_minus3_T
mat qVM2_D = p_beta_new_5*qVM2*p_beta_new_5_T + qcatt_e_minus2 * true_cov_p_5* qcatt_e_minus2_T


mat qv_dynamic = J(13,1,0)
forvalues i = 0/7 {
	mat qv_dynamic[`i'+6,1] = qV`i'_D[1,1]
}

mat qv_dynamic[1,1] = qVM6_D
mat qv_dynamic[2,1] = qVM5_D
mat qv_dynamic[3,1] = qVM4_D
mat qv_dynamic[4,1] = qVM3_D
mat qv_dynamic[5,1] = qVM2_D

mat qse_dynamic = J(13,1,0)
forvalues i = 1/13 {
	mat qse_dynamic[`i',1] = qv_dynamic[`i',1]^0.5
}


mat qt_dynamic = J(13,1,0)
forvalues i = 1/13 {
	mat qt_dynamic[`i',1] = qdynamic_effect[`i',1]/qse_dynamic[`i',1]
}

******************************** Draw Graph ******************************************************
******************************** No control ******************************************************

gen dynamic_effect = 0 in 5

forvalues i = 1/4 {
	replace dynamic_effect=dynamic_effect[`i'+1,1] in `i'
}

forvalues i = 6/14 {
	replace dynamic_effect=dynamic_effect[`i',1] in `i'
}

gen time_grap = -5 in 1

forvalues i = 2/14 {
	replace time_grap =`i'-6 in `i'
}

gen dynamic_effect_lc  = 0 in 5
gen dynamic_effect_uc  = 0 in 5 

forvalues i = 1/4 {
	replace dynamic_effect_lc =dynamic_effect[`i'+1,1]-1.96*se_dynamic[`i'+1,1] in `i'
	replace dynamic_effect_uc =dynamic_effect[`i'+1,1]+1.96*se_dynamic[`i'+1,1] in `i'
}

forvalues i = 6/14 {
	replace dynamic_effect_lc =dynamic_effect[`i',1]-1.96*se_dynamic[`i',1] in `i'
	replace dynamic_effect_uc =dynamic_effect[`i',1]+1.96*se_dynamic[`i',1] in `i'
}


twoway rcap dynamic_effect_uc dynamic_effect_lc time_grap, lstyle(ci) yline(0) xlabel(-5 [1] 7) ||  ///
       scatter dynamic_effect time_grap, mstyle(p1) xscale(range(-1 7))                       ///
       xtitle(Years since (until) adoption of Unilateral Divorce Laws)  ///
	   xlabel( -5 "-10" -4 "-8" -3 "-6" -2 "-4" -1 "-2" 0 "0" 1 "2" 2 "4" 3 "6" 4 "8" 5 "10" 6 "12" 7 "14~" ) ///
       legend(label(1 "95% Confidence Interval") label(2 "The Effect of Unilteral Law")) ///                     ///
       note("with 95% confidence interval")

	   *************************************
******************************** Linear Trend ******************************************************
	   *************************************
	   
gen ldynamic_effect = 0 in 5

forvalues i = 1/4 {
	replace ldynamic_effect=ldynamic_effect[`i'+1,1] in `i'
}

forvalues i = 6/14 {
	replace ldynamic_effect=ldynamic_effect[`i',1] in `i'
}

gen ldynamic_effect_lc  = 0 in 5
gen ldynamic_effect_uc  = 0 in 5 

forvalues i = 1/4 {
	replace ldynamic_effect_lc =ldynamic_effect[`i'+1,1]-1.96*lse_dynamic[`i'+1,1] in `i'
	replace ldynamic_effect_uc =ldynamic_effect[`i'+1,1]+1.96*lse_dynamic[`i'+1,1] in `i'
}

forvalues i = 6/14 {
	replace ldynamic_effect_lc =ldynamic_effect[`i',1]-1.96*lse_dynamic[`i',1] in `i'
	replace ldynamic_effect_uc =ldynamic_effect[`i',1]+1.96*lse_dynamic[`i',1] in `i'
}


twoway rcap ldynamic_effect_uc ldynamic_effect_lc time_grap, lstyle(ci) yline(0) xlabel(-5 [1] 7) ||  ///
       scatter ldynamic_effect time_grap, mstyle(p1) xscale(range(-1 7))                       ///
       xtitle(Years since (until) adoption of Unilateral Divorce Laws)  ///
	   xlabel( -5 "-10" -4 "-8" -3 "-6" -2 "-4" -1 "-2" 0 "0" 1 "2" 2 "4" 3 "6" 4 "8" 5 "10" 6 "12" 7 "14~" ) ///
       legend(label(1 "95% Confidence Interval") label(2 "The Effect of Unilteral Law")) ///                     ///
       note("with 95% confidence interval")

	   *************************************
******************************** Quadratic Trend ******************************************************
	   *************************************
	   
gen qdynamic_effect = 0 in 5

forvalues i = 1/4 {
	replace qdynamic_effect=qdynamic_effect[`i'+1,1] in `i'
}

forvalues i = 6/14 {
	replace qdynamic_effect=qdynamic_effect[`i',1] in `i'
}


gen qdynamic_effect_lc  = 0 in 5
gen qdynamic_effect_uc  = 0 in 5 

forvalues i = 1/4 {
	replace qdynamic_effect_lc =qdynamic_effect[`i'+1,1]-1.96*qse_dynamic[`i'+1,1] in `i'
	replace qdynamic_effect_uc =qdynamic_effect[`i'+1,1]+1.96*qse_dynamic[`i'+1,1] in `i'
}

forvalues i = 6/14 {
	replace qdynamic_effect_lc =qdynamic_effect[`i',1]-1.96*qse_dynamic[`i',1] in `i'
	replace qdynamic_effect_uc =qdynamic_effect[`i',1]+1.96*qse_dynamic[`i',1] in `i'
}



twoway rcap qdynamic_effect_uc qdynamic_effect_lc time_grap, lstyle(ci) yline(0) xlabel(-5 [1] 7) ||  ///
       scatter qdynamic_effect time_grap, mstyle(p1) xscale(range(-1 7))                       ///
       xtitle(Years since (until) adoption of Unilateral Divorce Laws)  ///
	   xlabel( -5 "-10" -4 "-8" -3 "-6" -2 "-4" -1 "-2" 0 "0" 1 "2" 2 "4" 3 "6" 4 "8" 5 "10" 6 "12" 7 "14~" ) ///
       legend(label(1 "95% Confidence Interval") label(2 "The Effect of Unilteral Law")) ///                     ///
       note("with 95% confidence interval")

	   
*********************************************************************
********Make alternative to \beta_{fe} in TWFE regression************
*********************************************************************

/* Calculate Proportion of ppl */


sum stpop if unilateral ==1 & year>1955 & year<1989 & n_itl>=0 & n_itl<=7
scalar total_treated = r(sum)


local j = 6
forvalues i = 0/7{

sum stpop if unilateral ==1 & year>1955 & year<1989 & n_itl==`i'
scalar total_treated_`i' = r(sum)
scalar proportion_`i' = total_treated_`i' / total_treated
mat p_fe_`j' = p_beta_new_`j' * proportion_`i'
local j = `j'+1

}

mat p_fe = p_fe_6 , p_fe_7 , p_fe_8 , p_fe_9 , p_fe_10 , p_fe_11 , p_fe_12 , p_fe_13 
mat p_fe_T = p_fe'

forvalues i = 0/7{
	forvalues j = 0/7{
		mat cov_p_`i'`j' = true_cov_p[51+`i'*10..60+`i'*10, 51+`j'*10..60+`j'*10 ]
	}
}


forvalues i = 0/7{
	forvalues j = 0/7{
		if `i' == `j' {
				mat cov_p_`i'`j'_fe = cov_p_`i'`j' * (proportion_`i')^2 
		}
		else if `i' !=`j' {
				mat cov_p_`i'`j'_fe = cov_p_`i'`j' * (proportion_`i') * (proportion_`j')
		}
	}
}

forvalues i = 0/7{
	mat cov_p_fe_`i' = cov_p_`i'0_fe, cov_p_`i'1_fe, cov_p_`i'2_fe, cov_p_`i'3_fe, cov_p_`i'4_fe, cov_p_`i'5_fe, cov_p_`i'6_fe, cov_p_`i'7_fe  
}

mat cov_p_fe =   cov_p_fe_0\cov_p_fe_1\cov_p_fe_2\cov_p_fe_3\cov_p_fe_4\cov_p_fe_5\cov_p_fe_6\ cov_p_fe_7  

***************************************************************************************************************    
/* No control */

reg y_residual $rhs_residuals if year>1955 & year<1989 [w=stpop], cluster(state)/* (9) in page 12. */

mat beta_fe_gl = e(b)[.,51..130]
mat beta_fe_gl_T = beta_fe_gl'

mat V_beta_fe_gl = e(V)[51..130,51..130]

mat beta_fe = p_fe * beta_fe_gl_T 
mat V_beta_fe = p_fe * V_beta_fe_gl  * p_fe_T + beta_fe_gl * cov_p_fe * beta_fe_gl_T
mat se_beta_fe = V_beta_fe[1,1]^(0.5)

****************************************************************************************************************
/* Linear Trend */

reg y_lresidual $rhs_lresiduals if year>1955 & year<1989 [w=stpop], cluster(state)

mat lbeta_fe_gl = e(b)[.,51..130]
mat lbeta_fe_gl_T = lbeta_fe_gl'

mat lV_beta_fe_gl = e(V)[51..130,51..130]

mat lbeta_fe = p_fe * lbeta_fe_gl_T 
mat lV_beta_fe = p_fe * lV_beta_fe_gl  * p_fe_T + lbeta_fe_gl * cov_p_fe * lbeta_fe_gl_T
mat lse_beta_fe = lV_beta_fe[1,1]^(0.5)




****************************************************************************************************************
/* Quadratic Trend */

reg y_qresidual $rhs_qresiduals if year>1955 & year<1989 [w=stpop], cluster(state)

mat qbeta_fe_gl = e(b)[.,51..130]
mat qbeta_fe_gl_T = qbeta_fe_gl'

mat qV_beta_fe_gl = e(V)[51..130,51..130]

mat qbeta_fe = p_fe * qbeta_fe_gl_T 
mat qV_beta_fe = p_fe * qV_beta_fe_gl  * p_fe_T + qbeta_fe_gl * cov_p_fe * qbeta_fe_gl_T
mat qse_beta_fe = qV_beta_fe[1,1]^(0.5)


/* Part 2 DD estimator Estimation */


***********************************************************************************
***********************************************************************************
***********************************************************************************
****************************DD estimator Estimation********************************
***********************************************************************************
***********************************************************************************
***********************************************************************************


/* Data Load */ 

see
clear

use "D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData\data\Divorce-Wolfers-AER.dta"
cd D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData


set seed 1234 /* For Bootstrap */  
encode st, gen(state) 


/* Calculate negative weights in TWFE */ 


twowayfeweights div_rate state year unilateral if year>1955 & year<1989, type(feTR)
xi i.st i.st*time   i.year i.years_unilateral
twowayfeweights div_rate state year unilateral if year>1955 & year<1989, type(feTR) controls(_IstXtime_* )
xi i.st i.st*time i.st*timesq i.year i.years_unilateral
twowayfeweights div_rate state year unilateral if year>1955 & year<1989, type(feTR) controls(_IstXtime_* _IstXtimea*)





/* Drop already-treated states in 1955 */ 


drop if lfdivlaw==1935
drop if lfdivlaw==1953


/* DD estimator */ 

******************************************************************************************
*************************************No Control*******************************************
******************************************************************************************

did_multiplegt div_rate state year unilateral if year>1955 & year<1989,  robust_dynamic placebo(10) dynamic(19) weight(stpop) breps(200) cluster(state) 



*************************************Save Effect ******************************************
mat DID_M = J(20,1,0)

forvalues i = 0/19{
	mat DID_M[`i'+1,1] =  e(effect_`i')
}

mat V_DID_M = J(20,20,0)

forvalues i = 0/19{
	forvalues j=0/19{
		if `i' == `j' {
			mat V_DID_M[`i'+1,`j'+1] = e(se_effect_`i')^2
		}
		else if `i' < `j' {
			mat V_DID_M[`i'+1,`j'+1] = e(cov_effects_`i'_`j') /*Note that V_DID_M[i,j] = e(cov_effects_`i'-1`j'-1) */
			mat V_DID_M[`j'+1,`i'+1] = e(cov_effects_`i'_`j')
		}
	}     
}

mat se_DID_M = J(20,1, 0)
forvalues i = 0/19{
	mat se_DID_M[`i'+1, 1] = e(se_effect_`i')
}
****************************************Save Placebo Effect********************************

mat DID_M_pl = J(10,1,0)
forvalues i = 1/10{
	mat DID_M_pl[`i',1] =  e(placebo_`i') /*Placebo 1 = e(placebo_1). See the definition in help*/
}

mat V_DID_M_pl = J(10,10,0)
forvalues i = 1/10{
	forvalues j = 1/10{
		if `i' == `j' {
			mat V_DID_M_pl[`i',`j'] = e(se_placebo_`i')^2
		}
		else if `i' < `j' {
			mat V_DID_M_pl[`i',`j'] = e(cov_placebo_`i'_`j')
			mat V_DID_M_pl[`j',`i'] = e(cov_placebo_`i'_`j')
		}
	}     
}

mat se_DID_M_pl = J(10,1,0)
forvalues i = 1/10{
	mat se_DID_M_pl[`i', 1] = e(se_effect_`i')
}




mat avg_DID_M = J(1,1,0)
mat avg_DID_M = e(estimates)[21,1]

mat avg_DID_M_SE = J(1,1,0)
mat avg_DID_M_SE = e(variances)[21,1]^0.5




******************************************************************************************
***************************************Linear Trend***************************************
******************************************************************************************

xi i.st*time

did_multiplegt div_rate state year unilateral if year>1955 & year<1989,  robust_dynamic placebo(10) dynamic(19) weight(stpop) breps(200) cluster(state) controls(_IstXtime_* )


*************************************Save Effect ******************************************

mat lDID_M = J(20,1,0)

forvalues i = 0/19{
	mat lDID_M[`i'+1,1] =  e(effect_`i')
}

mat lV_DID_M = J(20,20,0)

forvalues i = 0/19{
	forvalues j=0/19{
		if `i' == `j' {
			mat lV_DID_M[`i'+1,`j'+1] = e(se_effect_`i')^2
		}
		else if `i' < `j' {
			mat lV_DID_M[`i'+1,`j'+1] = e(cov_effects_`i'_`j')
			mat lV_DID_M[`j'+1,`i'+1] = e(cov_effects_`i'_`j')
		}
	}     
}

mat lse_DID_M = J(20,1, 0)
forvalues i = 0/19{
	mat lse_DID_M[`i'+1, 1] = e(se_effect_`i')
}

****************************************Save Placebo Effect********************************

mat lDID_M_pl = J(10,1,0)
forvalues i = 1/10{
	mat lDID_M_pl[`i',1] =  e(placebo_`i') /*Placebo 1 = e(placebo_1). See the definition in help*/
}

mat lV_DID_M_pl = J(10,10,0)
forvalues i = 1/10{
	forvalues j = 1/10{
		if `i' == `j' {
			mat lV_DID_M_pl[`i',`j'] = e(se_placebo_`i')^2
		}
		else if `i' < `j' {
			mat lV_DID_M_pl[`i',`j'] = e(cov_placebo_`i'_`j')
			mat lV_DID_M_pl[`j',`i'] = e(cov_placebo_`i'_`j')
		}
	}     
}

mat lse_DID_M_pl = J(10,1,0)
forvalues i = 1/10{
	mat lse_DID_M_pl[`i', 1] = e(se_effect_`i')
}


mat lavg_DID_M = J(1,1,0)
mat lavg_DID_M = e(estimates)[21,1]

mat lavg_DID_M_SE = J(1,1,0)
mat lavg_DID_M_SE = e(variances)[21,1]^0.5

******************************************************************************************
***************************************Quadratic Trend************************************
******************************************************************************************

xi i.st*time i.st*timesq


did_multiplegt div_rate state year unilateral if year>1955 & year<1989,  robust_dynamic placebo(10) dynamic(19) weight(stpop) breps(200) cluster(state) controls(_IstXtime_* _IstXtimea*)


*************************************Save Effect ******************************************

mat qDID_M = J(20,1,0)

forvalues i = 0/19{
	mat qDID_M[`i'+1,1] =  e(effect_`i')
}

mat qV_DID_M = J(20,20,0)

forvalues i = 0/19{
	forvalues j=0/19{
		if `i' == `j' {
			mat qV_DID_M[`i'+1,`j'+1] = e(se_effect_`i')^2
		}
		else if `i' < `j' {
			mat qV_DID_M[`i'+1,`j'+1] = e(cov_effects_`i'_`j')
			mat qV_DID_M[`j'+1,`i'+1] = e(cov_effects_`i'_`j')
		}
	}     
}

mat qse_DID_M = J(20,1, 0)
forvalues i = 0/19{
	mat qse_DID_M[`i'+1, 1] = e(se_effect_`i')
}

****************************************Save Placebo Effect********************************

mat qDID_M_pl = J(10,1,0)
forvalues i = 1/10{
	mat qDID_M_pl[`i',1] =  e(placebo_`i') /*Placebo 1 = e(placebo_1). See the definition in help*/
}

mat qV_DID_M_pl = J(10,10,0)
forvalues i = 1/10{
	forvalues j = 1/10{
		if `i' == `j' {
			mat qV_DID_M_pl[`i',`j'] = e(se_placebo_`i')^2
		}
		else if `i' < `j' {
			mat qV_DID_M_pl[`i',`j'] = e(cov_placebo_`i'_`j')
			mat qV_DID_M_pl[`j',`i'] = e(cov_placebo_`i'_`j')
		}
	}     
}

mat qse_DID_M_pl = J(10,1,0)
forvalues i = 1/10{
	mat qse_DID_M_pl[`i', 1] = e(se_effect_`i')
}



mat qavg_DID_M = J(1,1,0)
mat qavg_DID_M = e(estimates)[21,1]

mat qavg_DID_M_SE = J(1,1,0)
mat qavg_DID_M_SE = e(variances)[21,1]^0.5


************************************************************************************************
******************Calculate dynamic effects comaprable to  Abraham Sun**************************
************************************************************************************************


/* 1-1. Calculate proportion to each one period dynamic effects */
gen length_policy = year - lfdivlaw if year>1955 & year<1989

mat treated_pop = J(20,1,0)
forvalues i = 0/19{
	sum stpop if length_policy==`i'
	mat treated_pop[`i'+1,1] = r(sum)
}

mat placebo_treated_pop = J(10,1,0)
forvalues i = 2/11{
	local j=-`i'
	sum stpop if length_policy==`j'
	mat placebo_treated_pop[`i'-1,1] = r(sum) /*n th row value is placebo -`n+1' population*/
}


foreach i in 1 3 5 7 9 11 13 15 {
	local j = `i'+1
	mat pDID_`i' = J(1,20,0)
	scalar ppl_`i' =  treated_pop[`i',1]
	scalar ppl_`j' =  treated_pop[`j',1]
	scalar ppl_total_`i'`j' = treated_pop[`i',1] + treated_pop[`j',1]
	scalar p_ppl`i' = ppl_`i'/ppl_total_`i'`j'
	scalar p_ppl`j' = ppl_`j'/ppl_total_`i'`j'
	
	mat pDID_`i'[1,`i'] =   p_ppl`i'
	mat pDID_`i'[1,`i'+1] = p_ppl`j'

}

forvalues i=15/20 {
	
	mat pDID_15[1,`i'] = treated_pop[`i',1] / (treated_pop[15,1] + treated_pop[16,1]+treated_pop[17,1] + treated_pop[18,1]+treated_pop[19,1] + treated_pop[20,1])
}

/* 1-2. Calculate proportion to each placebo dynamic effects */


local k=3
local l=4
forvalues i=1/4{
	mat pDID_placebo_`i' = J(1,10,0)
	mat pDID_placebo_`i'[1,`k'] =  placebo_treated_pop[`k',1]/(placebo_treated_pop[`k',1]+placebo_treated_pop[`l',1])
	mat pDID_placebo_`i'[1,`l'] =  placebo_treated_pop[`l',1]/(placebo_treated_pop[`k',1]+placebo_treated_pop[`l',1])
	mat pDID_placebo_`i'_T = pDID_placebo_`i''
	local k = `k'+1
	local l = `l'+1
}


/* 2. Calculate Abraham Sun Dynamic Effects */

mat beta_DID_M = J(8,1,0)
mat V_beta_DID_M = J(8,1,0)
mat se_beta_DID_M = J(8,1,0)

forvalues i = 1/8{
	local j = `i'*2 -1
	mat pDID_`j'_T = pDID_`j''
	mat beta_DID_M[`i',1] = pDID_`j' * DID_M
	mat V_beta_DID_M[`i',1] = pDID_`j' * V_DID_M * pDID_`j'_T 
	mat se_beta_DID_M[`i',1] = V_beta_DID_M[`i',1]^0.5
}

/* 3. Calculate Abraham Sun Placebo Effects */

mat placebo_DID_M = J(4,1,0)
mat V_placebo_DID_M = J(4,1,0)
mat se_placebo_DID_M = J(4,1,0)

forvalues i = 1/4{
	mat placebo_DID_M[`i',1] = pDID_placebo_`i' * DID_M_pl
	mat V_placebo_DID_M[`i',1] = pDID_placebo_`i'  * V_DID_M_pl * pDID_placebo_`i'_T 
	mat se_placebo_DID_M[`i',1] =  V_placebo_DID_M[`i',1]^0.5
}

mat dynamic_DID_M = J(12,1,0)

mat dynamic_DID_M[1,1] = placebo_DID_M[4,1]
mat dynamic_DID_M[2,1] = placebo_DID_M[3,1]
mat dynamic_DID_M[3,1] = placebo_DID_M[2,1]
mat dynamic_DID_M[4,1] = placebo_DID_M[1,1]

forvalues i = 5/12{
	mat dynamic_DID_M[`i',1] = beta_DID_M[`i'-4,1]
}

mat se_dynamic_DID_M = J(12,1,0)

mat se_dynamic_DID_M[1,1] = se_placebo_DID_M[4,1]
mat se_dynamic_DID_M[2,1] = se_placebo_DID_M[3,1]
mat se_dynamic_DID_M[3,1] = se_placebo_DID_M[2,1]
mat se_dynamic_DID_M[4,1] = se_placebo_DID_M[1,1]

forvalues i = 5/12{
	mat se_dynamic_DID_M[`i',1] = se_beta_DID_M[`i'-4,1]
}

/* 4. Draw the graph */

gen dynamic_DID_M = 0 in 5

forvalues i = 1/4 {
	replace dynamic_DID_M=dynamic_DID_M[`i',1] in `i'
}

forvalues i = 6/13 {
	replace dynamic_DID_M=dynamic_DID_M[`i'-1,1] in `i'
}


gen time_grap = -5 in 1

forvalues i = 2/14 {
	replace time_grap =`i'-6 in `i'
}


gen dynamic_DID_M_lc  = 0 in 5
gen dynamic_DID_M_uc  = 0 in 5 

forvalues i = 1/4 {
	replace dynamic_DID_M_lc =dynamic_DID_M[`i',1]-1.96*se_dynamic_DID_M[`i',1] in `i'
	replace dynamic_DID_M_uc =dynamic_DID_M[`i',1]+1.96*se_dynamic_DID_M[`i',1] in `i'
}

forvalues i = 6/13 {
	replace dynamic_DID_M_lc =dynamic_DID_M[`i'-1,1]-1.96*se_dynamic_DID_M[`i'-1,1] in `i'
	replace dynamic_DID_M_uc =dynamic_DID_M[`i'-1,1]+1.96*se_dynamic_DID_M[`i'-1,1] in `i'
}


twoway rcap dynamic_DID_M_uc dynamic_DID_M_lc time_grap, lstyle(ci) yline(0) xlabel(-5 [1] 7) ||  ///
       scatter dynamic_DID_M time_grap, mstyle(p1) xscale(range(-1 7))                       ///
       xtitle(Years since (until) adoption of Unilateral Divorce Laws)  ///
	   xlabel(-5 "-10" -4 "-8" -3 "-6" -2 "-4" -1 "-2" 0 "0" 1 "2" 2 "4" 3 "6" 4 "8" 5 "10" 6 "12" 7 "14~" ) ///
       legend(label(1 "95% Confidence Interval") label(2 "The Effect of Unilteral Law")) ///                     ///
       note("with 95% confidence interval")
	   
	   
************************************************************************************************
********************Do this again for linear trend**********************************************
************************************************************************************************


/* 1-1. Calculate proportion to each one period dynamic effects */

foreach i in 1 3 5 7 9 11 13 15 {
	mat lpDID_`i' = pDID_`i'[1,1..20] 
}

mat lDID_M = lDID_M[1..20,1] 
mat lV_DID_M  = lV_DID_M[1..20,1..20] 

/* 2. Calculate Abraham Sun Dynamic Effects */

mat lbeta_DID_M = J(8,1,0)
mat lV_beta_DID_M = J(8,1,0)
mat lse_beta_DID_M = J(8,1,0)

forvalues i = 1/8{
	local j = `i'*2 -1
	mat lpDID_`j'_T = lpDID_`j''
	mat lbeta_DID_M[`i',1] = lpDID_`j' * lDID_M
	mat lV_beta_DID_M[`i',1] = lpDID_`j' * lV_DID_M * lpDID_`j'_T 
	mat lse_beta_DID_M[`i',1] = lV_beta_DID_M[`i',1]^0.5
}

/* 3. Calculate Abraham Sun Placebo Effects */

mat lplacebo_DID_M = J(4,1,0)
mat lV_placebo_DID_M = J(4,1,0)
mat lse_placebo_DID_M = J(4,1,0)

forvalues i = 1/4{
	mat lplacebo_DID_M[`i',1] = pDID_placebo_`i' * lDID_M_pl
	mat lV_placebo_DID_M[`i',1] = pDID_placebo_`i'  * lV_DID_M_pl * pDID_placebo_`i'_T 
	mat lse_placebo_DID_M[`i',1] =  lV_placebo_DID_M[`i',1]^0.5
}

mat ldynamic_DID_M = J(12,1,0)
mat ldynamic_DID_M[1,1] = lplacebo_DID_M[4,1]
mat ldynamic_DID_M[2,1] = lplacebo_DID_M[3,1]
mat ldynamic_DID_M[3,1] = lplacebo_DID_M[2,1]
mat ldynamic_DID_M[4,1] = lplacebo_DID_M[1,1]

forvalues i = 5/12{
	mat ldynamic_DID_M[`i',1] = lbeta_DID_M[`i'-4,1]
}

mat lse_dynamic_DID_M = J(12,1,0)
mat lse_dynamic_DID_M[1,1] = lse_placebo_DID_M[4,1]
mat lse_dynamic_DID_M[2,1] = lse_placebo_DID_M[3,1]
mat lse_dynamic_DID_M[3,1] = lse_placebo_DID_M[2,1]
mat lse_dynamic_DID_M[4,1] = lse_placebo_DID_M[1,1]

forvalues i = 5/12{
	mat lse_dynamic_DID_M[`i',1] = lse_beta_DID_M[`i'-4,1]
}



/* 4. Draw the graph */

gen ldynamic_DID_M = 0 in 5

forvalues i = 1/4 {
	replace ldynamic_DID_M=ldynamic_DID_M[`i',1] in `i'
}

forvalues i = 6/13 {
	replace ldynamic_DID_M=ldynamic_DID_M[`i'-1,1] in `i'
}


gen ldynamic_DID_M_lc  = 0 in 5
gen ldynamic_DID_M_uc  = 0 in 5 

forvalues i = 1/4 {
	replace ldynamic_DID_M_lc =ldynamic_DID_M[`i',1]-1.96*lse_dynamic_DID_M[`i',1] in `i'
	replace ldynamic_DID_M_uc =ldynamic_DID_M[`i',1]+1.96*lse_dynamic_DID_M[`i',1] in `i'
}

forvalues i = 6/13 {
	replace ldynamic_DID_M_lc =ldynamic_DID_M[`i'-1,1]-1.96*lse_dynamic_DID_M[`i'-1,1] in `i'
	replace ldynamic_DID_M_uc =ldynamic_DID_M[`i'-1,1]+1.96*lse_dynamic_DID_M[`i'-1,1] in `i'
}


twoway rcap ldynamic_DID_M_uc ldynamic_DID_M_lc time_grap, lstyle(ci) yline(0) xlabel(-5 [1] 7) ||  ///
       scatter ldynamic_DID_M time_grap, mstyle(p1) xscale(range(-1 7))                       ///
       xtitle(Years since (until) adoption of Unilateral Divorce Laws)  ///
	   xlabel(-5 "-10" -4 "-8" -3 "-6" -2 "-4" -1 "-2" 0 "0" 1 "2" 2 "4" 3 "6" 4 "8" 5 "10" 6 "12" 7 "14~" ) ///
       legend(label(1 "95% Confidence Interval") label(2 "The Effect of Unilteral Law")) ///                     ///
       note("with 95% confidence interval")


	   
  
************************************************************************************************	   
********************Do this again for Quadratic trend*******************************************
************************************************************************************************

/* 1-1. Calculate proportion to each one period dynamic effects */

foreach i in 1 3 5 7 9 11 13 15 {
	mat qpDID_`i' = pDID_`i'[1,1..20] 
}

mat qDID_M = qDID_M[1..20,1] 
mat qV_DID_M  = qV_DID_M[1..20,1..20] 

/* 2. Calculate Abraham Sun Dynamic Effects */

mat qbeta_DID_M = J(8,1,0)
mat qV_beta_DID_M = J(8,1,0)
mat qse_beta_DID_M = J(8,1,0)

forvalues i = 1/8{
	local j = `i'*2 -1
	mat qpDID_`j'_T = qpDID_`j''
	mat qbeta_DID_M[`i',1] = qpDID_`j' * qDID_M
	mat qV_beta_DID_M[`i',1] = qpDID_`j' * qV_DID_M * qpDID_`j'_T 
	mat qse_beta_DID_M[`i',1] = qV_beta_DID_M[`i',1]^0.5
}

/* 3. Calculate Abraham Sun Placebo Effects */

mat qplacebo_DID_M = J(4,1,0)
mat qV_placebo_DID_M = J(4,1,0)
mat qse_placebo_DID_M = J(4,1,0)

forvalues i = 1/4{
	mat qplacebo_DID_M[`i',1] = pDID_placebo_`i' * qDID_M_pl
	mat qV_placebo_DID_M[`i',1] = pDID_placebo_`i'  * qV_DID_M_pl * pDID_placebo_`i'_T 
	mat qse_placebo_DID_M[`i',1] =  qV_placebo_DID_M[`i',1]^0.5
}

mat qdynamic_DID_M = J(12,1,0)
mat qdynamic_DID_M[1,1] = qplacebo_DID_M[4,1]
mat qdynamic_DID_M[2,1] = qplacebo_DID_M[3,1]
mat qdynamic_DID_M[3,1] = qplacebo_DID_M[2,1]
mat qdynamic_DID_M[4,1] = qplacebo_DID_M[1,1]

forvalues i = 5/12{
	mat qdynamic_DID_M[`i',1] = qbeta_DID_M[`i'-4,1]
}

mat qse_dynamic_DID_M = J(12,1,0)
mat qse_dynamic_DID_M[1,1] = qse_placebo_DID_M[4,1]
mat qse_dynamic_DID_M[2,1] = qse_placebo_DID_M[3,1]
mat qse_dynamic_DID_M[3,1] = qse_placebo_DID_M[2,1]
mat qse_dynamic_DID_M[4,1] = qse_placebo_DID_M[1,1]


forvalues i = 5/12{
	mat qse_dynamic_DID_M[`i',1] = qse_beta_DID_M[`i'-4,1]
}



/* 4. Draw the graph */

gen qdynamic_DID_M = 0 in 5

forvalues i = 1/4 {
	replace qdynamic_DID_M = qdynamic_DID_M[`i',1] in `i'
}

forvalues i = 6/13 {
	replace qdynamic_DID_M = qdynamic_DID_M[`i'-1,1] in `i'
}


gen qdynamic_DID_M_lc  = 0 in 5
gen qdynamic_DID_M_uc  = 0 in 5 

forvalues i = 1/4 {
	replace qdynamic_DID_M_lc = qdynamic_DID_M[`i',1] - 1.96 * qse_dynamic_DID_M[`i',1] in `i'
	replace qdynamic_DID_M_uc = qdynamic_DID_M[`i',1] + 1.96 * qse_dynamic_DID_M[`i',1] in `i'
}

forvalues i = 6/13 {
	replace qdynamic_DID_M_lc =qdynamic_DID_M[`i'-1,1]-1.96*qse_dynamic_DID_M[`i'-1,1] in `i'
	replace qdynamic_DID_M_uc =qdynamic_DID_M[`i'-1,1]+1.96*qse_dynamic_DID_M[`i'-1,1] in `i'
}


twoway rcap qdynamic_DID_M_uc qdynamic_DID_M_lc time_grap, lstyle(ci) yline(0) xlabel(-5 [1] 7) ||  ///
       scatter qdynamic_DID_M time_grap, mstyle(p1) xscale(range(-1 7))                       ///
       xtitle(Years since (until) adoption of Unilateral Divorce Laws)  ///
	   xlabel(-5 "-10" -4 "-8" -3 "-6" -2 "-4" -1 "-2" 0 "0" 1 "2" 2 "4" 3 "6" 4 "8" 5 "10" 6 "12" 7 "14~" ) ///
       legend(label(1 "95% Confidence Interval") label(2 "The Effect of Unilteral Law")) ///                     ///
       note("with 95% confidence interval")

	   
	     
	   
	   ************************************** Alternative to TWFE regression**********************
	   ****************Average of dynamic effects weighting on state population*******************
	   *******************************************************************************************
	   
	   
sum stpop if unilateral ==1 & year>1955 & year<1989 & length_policy >=0 & length_policy <20
scalar total_treated = r(sum)


mat pbeta_fe = J(1,20,0)
forvalues i = 0/19{
	mat pbeta_fe[1,`i'+1] = treated_pop[`i'+1,1]/total_treated
}
mat pbeta_fe_T = pbeta_fe'

/* No control */

mat beta_fe_DID_M = J(1,1,0)
mat V_beta_fe_DID_M = J(1,1,0)
mat se_beta_fe_DID_M = J(1,1,0)

mat beta_fe_DID_M[1,1] = pbeta_fe * DID_M
mat V_beta_fe_DID_M[1,1] = pbeta_fe * V_DID_M * pbeta_fe_T
mat se_beta_fe_DID_M[1,1] = V_beta_fe_DID_M[1,1]^0.5


sum stpop if unilateral ==1 & year>1955 & year<1989 & length_policy >=0 & length_policy <20
scalar ltotal_treated = r(sum)

/* Linear */

mat lpbeta_fe = J(1,20,0)
forvalues i = 0/19{
	mat lpbeta_fe[1,`i'+1] = treated_pop[`i'+1,1]/ltotal_treated
}
mat lpbeta_fe_T = lpbeta_fe'
mat lbeta_fe_DID_M = J(1,1,0)
mat lV_beta_fe_DID_M = J(1,1,0)
mat lse_beta_fe_DID_M = J(1,1,0)

mat lbeta_fe_DID_M[1,1] = lpbeta_fe * lDID_M
mat lV_beta_fe_DID_M[1,1] = lpbeta_fe * lV_DID_M * lpbeta_fe_T
mat lse_beta_fe_DID_M[1,1] = lV_beta_fe_DID_M[1,1]^0.5

/* Quadratic */

mat qbeta_fe_DID_M = J(1,1,0)
mat qV_beta_fe_DID_M = J(1,1,0)
mat qse_beta_fe_DID_M = J(1,1,0)

mat qbeta_fe_DID_M[1,1] = lpbeta_fe * qDID_M
mat qV_beta_fe_DID_M[1,1] = lpbeta_fe * qV_DID_M * lpbeta_fe_T
mat qse_beta_fe_DID_M[1,1] = qV_beta_fe_DID_M[1,1]^0.5

*******************Average of Dynamic Effects 20 periods (equal weights) **********************************

mat dynamic_pbeta_fe = J(1,20,0)
forvalues i = 0/19{
	mat dynamic_pbeta_fe[1,`i'+1] = 1/20
}
mat dynamic_pbeta_fe_T = dynamic_pbeta_fe'

mat dynamic_beta_fe = J(1,1,0)
mat dynamic_V_beta_fe = J(1,1,0)
mat dynamic_se_beta_fe = J(1,1,0)

mat dynamic_beta_fe[1,1] = dynamic_pbeta_fe * DID_M
mat dynamic_V_beta_fe[1,1] = dynamic_pbeta_fe * V_DID_M * dynamic_pbeta_fe_T
mat dynamic_se_beta_fe[1,1] = dynamic_V_beta_fe[1,1]^0.5

*******************Average of Dynamic Effects 20 periods (equal weights)  - Linear ****************************

mat ldynamic_pbeta_fe = J(1,20,0)
forvalues i = 0/16{
	mat ldynamic_pbeta_fe[1,`i'+1] = 1/20
}
mat ldynamic_pbeta_fe_T = ldynamic_pbeta_fe'

mat ldynamic_beta_fe = J(1,1,0)
mat ldynamic_V_beta_fe = J(1,1,0)
mat ldynamic_se_beta_fe = J(1,1,0)

mat ldynamic_beta_fe[1,1] = ldynamic_pbeta_fe * lDID_M
mat ldynamic_V_beta_fe[1,1] = ldynamic_pbeta_fe * lV_DID_M * ldynamic_pbeta_fe_T
mat ldynamic_se_beta_fe[1,1] = ldynamic_V_beta_fe[1,1]^0.5

*****************Average of Dynamic Effects 20 periods (equal weights)  - Quadratic **************************
mat qdynamic_pbeta_fe = J(1,20,0)
forvalues i = 0/16{
	mat qdynamic_pbeta_fe[1,`i'+1] = 1/20
}
mat qdynamic_pbeta_fe_T = qdynamic_pbeta_fe'

mat qdynamic_beta_fe = J(1,1,0)
mat qdynamic_V_beta_fe = J(1,1,0)
mat qdynamic_se_beta_fe = J(1,1,0)

mat qdynamic_beta_fe[1,1] = qdynamic_pbeta_fe * qDID_M
mat qdynamic_V_beta_fe[1,1] = qdynamic_pbeta_fe * qV_DID_M * qdynamic_pbeta_fe_T
mat qdynamic_se_beta_fe[1,1] = qdynamic_V_beta_fe[1,1]^0.5



/* Part 3 */


****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************
**********************Estimate Biases in Event study regressions************************************************
****************************************************************************************************************
****************************************************************************************************************
****************************************************************************************************************

/*Data Load*/

clear

use "D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData\data\Divorce-Wolfers-AER.dta"

/* Matrix Definition 

mat list w_el_* : Matrix of w_el_* in Abraham and Sun.
mat list Sum_*: To check whether Abraham Sun's proposition is right or not
mat list AbsSum_* : Measure of bias 


*/

cd D:\UCSB\2nd_year_2018\ECON245C\Wolfers\DataAppendix\Revisiting_CodeData


encode st, gen(state) 


**********************Generate 1{E_i=e} and D_{i,t}^l in my paper **********************
gen event = lfdivlaw  /* Event: Cohort */ 
tab event if year>1955 & year<1989, gen(event_) /*Generate 1{E_i=e} */

drop event_13


gen itl = year - event if year>1955 & year<1989 /* This will use to make D_{it}^l where l = E_i- t */


*** n_itl \equiv D_{i,t}^l in Abraham paper.***

gen n_itl = -6 if itl<=-11 
replace n_itl = -5 if itl>=-10 & itl<=-9 
replace n_itl = -4 if itl>=-8 & itl<=-7 
replace n_itl = -3 if itl>=-6 & itl<=-5 
replace n_itl = -2 if itl>=-4 & itl<=-3 
replace n_itl = -1 if itl>=-2 & itl<=-1 
replace n_itl = 0 if itl>=0 & itl<=1  
replace n_itl = 1 if itl>=2 & itl<=3  
replace n_itl = 2 if itl>=4 & itl<=5  
replace n_itl = 3 if itl>=6 & itl<=7  
replace n_itl = 4 if itl>=8 & itl<=9   
replace n_itl = 5 if itl>=10 & itl<=11 
replace n_itl = 6 if itl>=12 & itl<=13 
replace n_itl = 7 if itl>=14


replace n_itl = 99 if lfdivlaw==2000
tab n_itl if year>1955 & year<1989,  gen(n_itl_) 
drop n_itl_15



local list_itl "n_itl_*"
local list_event "event_*"

**************************Generate 1{E_i=e}*D_{i,t}^l************************************************

foreach v of varlist `list_itl' {
	foreach i of varlist `list_event'{
		gen `v'_`i' = `v'*`i'
	}
}


**************************Row: D_{it}^l Colum: Event************************************************

forvalues k = 7/14 {
matrix w_el_`k' = J(14,12,0)
		foreach j of numlist 1/14 {
				forvalues i = 1/12 {
					quietly reg n_itl_`j'_event_`i' i.state i.year n_itl_7-n_itl_14 if year>1955 & year<1989 [w=stpop]
					mat w_el_`k'[`j',`i']=_b[n_itl_`k']
		}
	}

}

/*w_el_k[j,i] is equal to w_{i,j}^k. That is, w_{i,j}^k is weight for average effect j periods from the initial treament for the cohoprt of units first treated at time i in beta_k */

forvalues u = 7/14{
	mat list w_el_`u'
}



mata: st_matrix("Sum_7", rowsum(st_matrix("w_el_7")))
mata: st_matrix("Sum_8", rowsum(st_matrix("w_el_8")))
mata: st_matrix("Sum_9", rowsum(st_matrix("w_el_9")))
mata: st_matrix("Sum_10", rowsum(st_matrix("w_el_10")))
mata: st_matrix("Sum_11", rowsum(st_matrix("w_el_11")))
mata: st_matrix("Sum_12", rowsum(st_matrix("w_el_12")))
mata: st_matrix("Sum_13", rowsum(st_matrix("w_el_13")))
mata: st_matrix("Sum_14", rowsum(st_matrix("w_el_14")))

mata: st_matrix("abs_w_el_7", abs(st_matrix("w_el_7")))
mata: st_matrix("abs_w_el_8", abs(st_matrix("w_el_8")))
mata: st_matrix("abs_w_el_9", abs(st_matrix("w_el_9")))
mata: st_matrix("abs_w_el_10", abs(st_matrix("w_el_10")))
mata: st_matrix("abs_w_el_11", abs(st_matrix("w_el_11")))
mata: st_matrix("abs_w_el_12", abs(st_matrix("w_el_12")))
mata: st_matrix("abs_w_el_13", abs(st_matrix("w_el_13")))
mata: st_matrix("abs_w_el_14", abs(st_matrix("w_el_14")))

mata: st_matrix("n_absSum_7", rowsum(st_matrix("abs_w_el_7")))
mata: st_matrix("n_absSum_8", rowsum(st_matrix("abs_w_el_8")))
mata: st_matrix("n_absSum_9", rowsum(st_matrix("abs_w_el_9")))
mata: st_matrix("n_absSum_10", rowsum(st_matrix("abs_w_el_10")))
mata: st_matrix("n_absSum_11", rowsum(st_matrix("abs_w_el_11")))
mata: st_matrix("n_absSum_12", rowsum(st_matrix("abs_w_el_12")))
mata: st_matrix("n_absSum_13", rowsum(st_matrix("abs_w_el_13")))
mata: st_matrix("n_absSum_14", rowsum(st_matrix("abs_w_el_14")))




****************Linear Form**********************


xi i.st i.st*time i.year


forvalues k = 7/14 {
matrix linear_w_el_`k' = J(14,12,0)
		foreach j of numlist 1/14 {
				forvalues i = 1/12 {
					quietly reg n_itl_`j'_event_`i' _Iyear_* _Ist_* _IstXtime_* n_itl_7-n_itl_14 if year>1955 & year<1989 [w=stpop]
					mat linear_w_el_`k'[`j',`i']=_b[n_itl_`k']
		}
	}

}

/*w_el_k[j,i] is equal to w_{i,j}^k. That is, w_{i,j}^k is weight for average effect j periods from the initial treament for the cohoprt of units first treated at time i in beta_k */

forvalues u = 7/14{
	mat list linear_w_el_`u'
}



mata: st_matrix("linear_Sum_7", rowsum(st_matrix("linear_w_el_7")))
mata: st_matrix("linear_Sum_8", rowsum(st_matrix("linear_w_el_8")))
mata: st_matrix("linear_Sum_9", rowsum(st_matrix("linear_w_el_9")))
mata: st_matrix("linear_Sum_10", rowsum(st_matrix("linear_w_el_10")))
mata: st_matrix("linear_Sum_11", rowsum(st_matrix("linear_w_el_11")))
mata: st_matrix("linear_Sum_12", rowsum(st_matrix("linear_w_el_12")))
mata: st_matrix("linear_Sum_13", rowsum(st_matrix("linear_w_el_13")))
mata: st_matrix("linear_Sum_14", rowsum(st_matrix("linear_w_el_14")))


mata: st_matrix("linear_abs_w_el_7", abs(st_matrix("linear_w_el_7")))
mata: st_matrix("linear_abs_w_el_8", abs(st_matrix("linear_w_el_8")))
mata: st_matrix("linear_abs_w_el_9", abs(st_matrix("linear_w_el_9")))
mata: st_matrix("linear_abs_w_el_10", abs(st_matrix("linear_w_el_10")))
mata: st_matrix("linear_abs_w_el_11", abs(st_matrix("linear_w_el_11")))
mata: st_matrix("linear_abs_w_el_12", abs(st_matrix("linear_w_el_12")))
mata: st_matrix("linear_abs_w_el_13", abs(st_matrix("linear_w_el_13")))
mata: st_matrix("linear_abs_w_el_14", abs(st_matrix("linear_w_el_14")))

mata: st_matrix("l_absSum_7", rowsum(st_matrix("linear_abs_w_el_7")))
mata: st_matrix("l_absSum_8", rowsum(st_matrix("linear_abs_w_el_8")))
mata: st_matrix("l_absSum_9", rowsum(st_matrix("linear_abs_w_el_9")))
mata: st_matrix("l_absSum_10", rowsum(st_matrix("linear_abs_w_el_10")))
mata: st_matrix("l_absSum_11", rowsum(st_matrix("linear_abs_w_el_11")))
mata: st_matrix("l_absSum_12", rowsum(st_matrix("linear_abs_w_el_12")))
mata: st_matrix("l_absSum_13", rowsum(st_matrix("linear_abs_w_el_13")))
mata: st_matrix("l_absSum_14", rowsum(st_matrix("linear_abs_w_el_14")))

forvalues u = 7/14{
	mat list linear_Sum_`u'
}


****************Quadratic Form**********************

xi i.st i.st*time i.st*timesq i.year 

forvalues k = 7/14 {
matrix q_w_el_`k' = J(14,12,0)
		foreach j of numlist 1/14 {
				forvalues i = 1/12 {
					quietly reg n_itl_`j'_event_`i'  _Iyear_* _Ist_* _IstXtime_* _IstXtimea* n_itl_7-n_itl_14 if year>1955 & year<1989 [w=stpop]
					mat q_w_el_`k'[`j',`i']=_b[n_itl_`k']
		}
	}

}

forvalues u = 7/14{
	mat list q_w_el_`u'
}




mata: st_matrix("q_Sum_7", rowsum(st_matrix("q_w_el_7")))
mata: st_matrix("q_Sum_8", rowsum(st_matrix("q_w_el_8")))
mata: st_matrix("q_Sum_9", rowsum(st_matrix("q_w_el_9")))
mata: st_matrix("q_Sum_10", rowsum(st_matrix("q_w_el_10")))
mata: st_matrix("q_Sum_11", rowsum(st_matrix("q_w_el_11")))
mata: st_matrix("q_Sum_12", rowsum(st_matrix("q_w_el_12")))
mata: st_matrix("q_Sum_13", rowsum(st_matrix("q_w_el_13")))
mata: st_matrix("q_Sum_14", rowsum(st_matrix("q_w_el_14")))


mata: st_matrix("q_abs_w_el_7", abs(st_matrix("q_w_el_7")))
mata: st_matrix("q_abs_w_el_8", abs(st_matrix("q_w_el_8")))
mata: st_matrix("q_abs_w_el_9", abs(st_matrix("q_w_el_9")))
mata: st_matrix("q_abs_w_el_10", abs(st_matrix("q_w_el_10")))
mata: st_matrix("q_abs_w_el_11", abs(st_matrix("q_w_el_11")))
mata: st_matrix("q_abs_w_el_12", abs(st_matrix("q_w_el_12")))
mata: st_matrix("q_abs_w_el_13", abs(st_matrix("q_w_el_13")))
mata: st_matrix("q_abs_w_el_14", abs(st_matrix("q_w_el_14")))

mata: st_matrix("q_absSum_7", rowsum(st_matrix("q_abs_w_el_7")))
mata: st_matrix("q_absSum_8", rowsum(st_matrix("q_abs_w_el_8")))
mata: st_matrix("q_absSum_9", rowsum(st_matrix("q_abs_w_el_9")))
mata: st_matrix("q_absSum_10", rowsum(st_matrix("q_abs_w_el_10")))
mata: st_matrix("q_absSum_11", rowsum(st_matrix("q_abs_w_el_11")))
mata: st_matrix("q_absSum_12", rowsum(st_matrix("q_abs_w_el_12")))
mata: st_matrix("q_absSum_13", rowsum(st_matrix("q_abs_w_el_13")))
mata: st_matrix("q_absSum_14", rowsum(st_matrix("q_abs_w_el_14")))

forvalues u = 7/14{
	mat list q_Sum_`u'
}

/*q_absSum_* is a vector containing sum of w_el^* in each row. For instance sum of weights on CATT_e,8 is avalable in row 8 of q_absSum_7. */




local specification n l q
foreach m of local specification {
forvalues u = 7/14{
svmat double `m'_absSum_`u', name(`m'_absSum_`u')
}

}

mat sum_nlq = J(14,3,0)
local specification n l q
local j=0

foreach m of local specification {
local j = `j'+1
forvalues u = 7/14{

mat sum_nlq[`u',`j'] = `m'_absSum_`u'[7,1]+`m'_absSum_`u'[8,1]+`m'_absSum_`u'[9,1]+`m'_absSum_`u'[10,1]+`m'_absSum_`u'[11,1]+`m'_absSum_`u'[12,1]+`m'_absSum_`u'[13,1]+`m'_absSum_`u'[14,1] -`m'_absSum_`u'[`u',1] 

}

}


